summaryrefslogtreecommitdiffstats
path: root/content/browser/renderer_host/render_view_host_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/renderer_host/render_view_host_delegate.h')
-rw-r--r--content/browser/renderer_host/render_view_host_delegate.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/content/browser/renderer_host/render_view_host_delegate.h b/content/browser/renderer_host/render_view_host_delegate.h
index e5fa672..50b9d44 100644
--- a/content/browser/renderer_host/render_view_host_delegate.h
+++ b/content/browser/renderer_host/render_view_host_delegate.h
@@ -382,8 +382,9 @@ class CONTENT_EXPORT RenderViewHostDelegate {
virtual void LostMouseLock() {}
// The page is trying to open a new page (e.g. a popup window). The window
// should be created associated with the given route, but it should not be
// shown yet. That should happen in response to ShowCreatedWindow.
// |params.window_container_type| describes the type of RenderViewHost
// container that is requested -- in particular, the window.open call may
// have specified 'background' and 'persistent' in the feature string.
@@ -394,6 +395,7 @@ class CONTENT_EXPORT RenderViewHostDelegate {
// Note: this is not called "CreateWindow" because that will clash with
// the Windows function which is actually a #define.
virtual void CreateNewWindow(
+ int render_process_id,
int route_id,
int main_frame_route_id,
const ViewHostMsg_CreateWindow_Params& params,
@@ -382,8 +382,9 @@ class CONTENT_EXPORT RenderViewHostDelegate {
virtual void LostMouseLock() {}
// The page is trying to open a new page (e.g. a popup window). The window
- // should be created associated with the given route, but it should not be
- // shown yet. That should happen in response to ShowCreatedWindow.
+ // should be created associated with the given |route_id| in process
+ // |render_process_id|, but it should not be shown yet. That should happen in
+ // response to ShowCreatedWindow.
// |params.window_container_type| describes the type of RenderViewHost
// container that is requested -- in particular, the window.open call may